==> libguestfs_1.32.2.orig.tar.gz: libguestfs-1.32.2/rescue/test-virt-rescue-suggest.sh <==
#!/bin/bash -
# test virt-rescue --suggest
# Copyright (C) 2014 Red Hat Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

export LANG=C
set -e

guest=../test-data/phony-guests/fedora.img

if [ ! -s "$guest" ]; then
    echo "$0: test skipped because $guest does not exist or is an empty file"
    exit 77
fi

rm -f virt-rescue-suggest.out

$VG virt-rescue --suggest "$guest" |
  grep '^mount ' |
  sed -r 's,/dev/[abce-ln-z]+d,/dev/sd,' > virt-rescue-suggest.out

if [ "$(cat virt-rescue-suggest.out)" != "mount /dev/VG/Root /sysroot/
mount /dev/sda1 /sysroot/boot
mount --bind /dev /sysroot/dev
mount --bind /dev/pts /sysroot/dev/pts
mount --bind /proc /sysroot/proc
mount --bind /sys /sysroot/sys" ]; then
    echo "$0: unexpected output from virt-rescue --suggest command:"
    cat virt-rescue-suggest.out
    exit 1
fi

rm virt-rescue-suggest.out

==> libguestfs_1.32.7.orig.tar.gz: libguestfs-1.32.7/rescue/test-virt-rescue-suggest.sh <==
#!/bin/bash -
# test virt-rescue --suggest
# Copyright (C) 2014 Red Hat Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

export LANG=C
set -e

guest=../test-data/phony-guests/fedora.img

if [ ! -s "$guest" ]; then
    echo "$0: test skipped because $guest does not exist or is an empty file"
    exit 77
fi

rm -f virt-rescue-suggest.out

$VG virt-rescue --suggest --format=raw -a "$guest" |
  grep '^mount ' |
  sed -r 's,/dev/[abce-ln-z]+d,/dev/sd,' > virt-rescue-suggest.out

if [ "$(cat virt-rescue-suggest.out)" != "mount /dev/VG/Root /sysroot/
mount /dev/sda1 /sysroot/boot
mount --bind /dev /sysroot/dev
mount --bind /dev/pts /sysroot/dev/pts
mount --bind /proc /sysroot/proc
mount --bind /sys /sysroot/sys" ]; then
    echo "$0: unexpected output from virt-rescue --suggest command:"
    cat virt-rescue-suggest.out
    exit 1
fi

rm virt-rescue-suggest.out
